## Requirements
- PyTorch (1.0+)
- python 3

## Installation 
```shell
pip install arm-pytorch-utilities
```
You can also install in editable mode with `python3 -m pip install -e .` so that modifications
in the repository are automatically synced with the installed library

## Testing
Install `pytest` if you don't have it, then run
```
py.test
```
